pub fn default_builder() -> ReqwestClientBuilderExpand description
Returns the default builder with all registered configurations applied.
pub fn default_builder() -> ReqwestClientBuilderReturns the default builder with all registered configurations applied.