Client

Struct Client 

pub struct Client { /* private fields */ }
A simple extendable client wrapper for http request with extra url sanitization.

Implementations

Source

impl Client

pub fn set_front_policy(&mut self, policy: FrontPolicy)

Set the policy for enabling fronting. If fronting was previously unset this will set it, and make it possible to enable (i.e FrontPolicy::Off will not enable it).

Calling this function sets a custom policy for this client, disconnecting it from the shared fronting policy – i.e. changes applied through Client::set_shared_front_policy will not be impact this client.

pub fn use_shared_front_policy(&mut self)

Set the fronting policy for this client to follow the shared policy.

pub fn set_shared_front_policy(policy: FrontPolicy)

Set the fronting policy for all clients using the shared policy.

Source

impl Client

pub fn new(base_url: Url, timeout: Option<Duration>) -> Self

Create a new http Client

pub fn new_url<U>( url: U, timeout: Option<Duration>, ) -> Result<Self, HttpClientError>
where U: IntoUrl,

Attempt to create a new http client from a something that can be converted to a URL

pub fn builder<U>(url: U) -> Result<ClientBuilder, HttpClientError>
where U: IntoUrl,

Creates a ClientBuilder to configure a Client.

This is the same as ClientBuilder::new().

pub fn change_base_urls(&mut self, new_urls: Vec<Url>)

Update the set of hosts that this client uses when sending API requests.

pub fn clone_with_new_url(&self, new_url: Url) -> Self

Create new instance of Client using the provided base url and existing client config

pub fn current_url(&self) -> &Url

Get the currently configured host that this client uses when sending API requests.

pub fn base_urls(&self) -> &[Url]

Get the currently configured host that this client uses when sending API requests.

pub fn base_urls_mut(&mut self) -> &mut [Url]

Get a mutable reference to the hosts that this client uses when sending API requests.

pub fn change_retry_limit(&mut self, limit: usize)

Change the currently configured limit on the number of retries for a request.