Url

Struct Url 

pub struct Url { /* private fields */ }
When configuring fronting, some configurations will require a specific backend host to be used for the request to be properly reverse proxied.

Implementations

Source

impl Url

pub fn new<U: IntoUrl>(url: U, fronts: Option<Vec<U>>) -> Result<Self, Error>

Create a new Url instance with the given something that can be parsed as a URL and optional tunneling domains

pub fn parse(s: &str) -> Result<Self, ParseError>

Parse an absolute URL from a string.

pub fn inner_url(&self) -> &Url

Returns the underlying URL

pub fn has_front(&self) -> bool

Returns true if the URL has a front domain set

pub fn front_str(&self) -> Option<&str>

Return the string representation of the current front host (domain or IP address) for this URL, if any.

pub fn fronts(&self) -> Option<&[Url]>

Returns the fronts

pub fn host_str(&self) -> Option<&str>

Return the string representation of the host (domain or IP address) for this URL, if any.

pub fn as_str(&self) -> &str

Return the serialization of this URL.

This is fast since that serialization is already stored in the inner url::Url struct.

pub fn update(&self) -> bool

Returns true if updating the front wraps back to the first front, or if no fronts are set

pub fn scheme(&self) -> &str

Return the scheme of this URL, lower-cased, as an ASCII string without the ‘:’ delimiter.

pub fn query_pairs(&self) -> Parse<'_>

Parse the URL’s query string, if any, as application/x-www-form-urlencoded and return an iterator of (key, value) pairs.

pub fn query_pairs_mut(&mut self) -> Serializer<'_, UrlQuery<'_>>

Manipulate this URL’s query string, viewed as a sequence of name/value pairs in application/x-www-form-urlencoded syntax.

pub fn set_query(&mut self, query: Option<&str>)

Change this URL’s query string. If query is None, this URL’s query string will be cleared.

pub fn set_path(&mut self, path: &str)

Change this URL’s path.

pub fn set_scheme(&mut self, scheme: &str)

Change this URL’s scheme.

pub fn set_host(&mut self, host: &str)

Change this URL’s host.

Removing the host (calling this with None) will also remove any username, password, and port number.

pub fn set_port(&mut self, port: u16)

Change this URL’s port number.

Note that default port numbers are not reflected in the serialization.

If this URL is cannot-be-a-base, does not have a host, or has the file scheme; do nothing and return Err.

pub fn path_segments(&self) -> Option<Split<'_, char>>

Return an object with methods to manipulate this URL’s path segments.

Return Err(()) if this URL is cannot-be-a-base.

pub fn path_segments_mut(&mut self) -> Result<PathSegmentsMut<'_>, ()>

Return an object with methods to manipulate this URL’s path segments.

Return Err(()) if this URL is cannot-be-a-base.