RequestPath

Trait RequestPath 

pub trait RequestPath: Debug {
    // Required method
    fn to_sanitized_segments(&self) -> Vec<&str>;
}
Defines a path that can be used to make a request to an API.

Required Methods

fn to_sanitized_segments(&self) -> Vec<&str>

Sanitise the request path by removing empty segments and trimming whitespace and slashes

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl RequestPath for &'_ [&'_ str]

Source

impl RequestPath for &String

Source

impl RequestPath for &str

Source

impl RequestPath for String

Source

impl<const N: usize> RequestPath for &[&str; N]

Implementors