ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
A ClientBuilder can be used to create a Client with custom configuration applied consistently and state tracked across subsequent requests.

Implementations

Source

impl ClientBuilder

pub fn with_fronting(self, policy: FrontPolicy) -> Self

Enable and configure request tunneling for API requests.

Source

impl ClientBuilder

pub fn dns_resolver<R: Resolve + 'static>(self, resolver: Arc<R>) -> Self

Override the DNS resolver implementation used by the underlying http client.

pub fn no_hickory_dns(self) -> Self

Override the DNS resolver implementation used by the underlying http client.

Source

impl ClientBuilder

pub fn new<U>(url: U) -> Result<Self, HttpClientError>
where U: IntoUrl,

Constructs a new ClientBuilder.

This is the same as Client::builder().

pub fn new_with_urls(urls: Vec<Url>) -> Result<Self, HttpClientError>

Constructs a new http ClientBuilder from a valid url.

pub fn add_url(self, url: Url) -> Self

Add an additional URL to the set usable by this constructed Client

pub fn with_timeout(self, timeout: Duration) -> Self

Enables a total request timeout other than the default.

The timeout is applied from when the request starts connecting until the response body has finished. Also considered a total deadline.

Default is DEFAULT_TIMEOUT.

pub fn with_retries(self, retry_limit: usize) -> Self

Sets the maximum number of retries for a request. This defaults to 0, indicating no retries.

Note that setting a retry limit of 3 (for example) will result in 4 attempts to send the request in the case that all are unsuccessful.

If multiple urls (or fronting configurations if enabled) are available, retried requests will be sent to the next URL in the list.

pub fn with_reqwest_builder(self, reqwest_builder: ClientBuilder) -> Self

Provide a pre-configured reqwest::ClientBuilder

pub fn with_user_agent<V>(self, value: V) -> Self

Sets the User-Agent header to be used by this client.

pub fn resolve_to_addrs( self, domain: &str, addrs: &[SocketAddr], ) -> ClientBuilder

Override DNS resolution for specific domains to particular IP addresses.

Set the port to 0 to use the conventional port for the given scheme (e.g. 80 for http). Ports in the URL itself will always be used instead of the port in the overridden addr.

pub fn with_serialization(self, format: SerializationFormat) -> Self

Set the serialization format for API requests and responses

pub fn with_bincode(self) -> Self

Configure the client to use bincode serialization

pub fn build(self) -> Result<Client, HttpClientError>

Returns a Client that uses this ClientBuilder configuration.