pub struct Url { /* private fields */ }Expand description
When configuring fronting, some configurations will require a specific backend host to be used for the request to be properly reverse proxied.
Implementations
Sourceimpl Url
impl Url
Sourcepub fn new<U: IntoUrl>(url: U, fronts: Option<Vec<U>>) -> Result<Self, Error>
pub fn new<U: IntoUrl>(url: U, fronts: Option<Vec<U>>) -> Result<Self, Error>
Create a new Url instance with the given something that can be parsed as a URL and
optional tunneling domains
Sourcepub fn parse(s: &str) -> Result<Self, ParseError>
pub fn parse(s: &str) -> Result<Self, ParseError>
Parse an absolute URL from a string.
Sourcepub fn front_str(&self) -> Option<&str>
pub fn front_str(&self) -> Option<&str>
Return the string representation of the current front host (domain or IP address) for this URL, if any.
Sourcepub fn host_str(&self) -> Option<&str>
pub fn host_str(&self) -> Option<&str>
Return the string representation of the host (domain or IP address) for this URL, if any.
Sourcepub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Return the serialization of this URL.
This is fast since that serialization is already stored in the inner url::Url struct.
Sourcepub fn update(&self) -> bool
pub fn update(&self) -> bool
Returns true if updating the front wraps back to the first front, or if no fronts are set
Sourcepub fn scheme(&self) -> &str
pub fn scheme(&self) -> &str
Return the scheme of this URL, lower-cased, as an ASCII string without the ‘:’ delimiter.
Sourcepub fn query_pairs(&self) -> Parse<'_>
pub fn query_pairs(&self) -> Parse<'_>
Parse the URL’s query string, if any, as application/x-www-form-urlencoded and return an iterator of (key, value) pairs.
Sourcepub fn query_pairs_mut(&mut self) -> Serializer<'_, UrlQuery<'_>>
pub fn query_pairs_mut(&mut self) -> Serializer<'_, UrlQuery<'_>>
Manipulate this URL’s query string, viewed as a sequence of name/value pairs in application/x-www-form-urlencoded syntax.
Sourcepub fn set_query(&mut self, query: Option<&str>)
pub fn set_query(&mut self, query: Option<&str>)
Change this URL’s query string. If query is None, this URL’s query string will be cleared.
Sourcepub fn set_scheme(&mut self, scheme: &str)
pub fn set_scheme(&mut self, scheme: &str)
Change this URL’s scheme.
Sourcepub fn set_host(&mut self, host: &str)
pub fn set_host(&mut self, host: &str)
Change this URL’s host.
Removing the host (calling this with None) will also remove any username, password, and port number.
Sourcepub fn set_port(&mut self, port: u16)
pub fn set_port(&mut self, port: u16)
Change this URL’s port number.
Note that default port numbers are not reflected in the serialization.
If this URL is cannot-be-a-base, does not have a host, or has the file scheme; do nothing and return Err.
Sourcepub fn path_segments(&self) -> Option<Split<'_, char>>
pub fn path_segments(&self) -> Option<Split<'_, char>>
Return an object with methods to manipulate this URL’s path segments.
Return Err(()) if this URL is cannot-be-a-base.
Sourcepub fn path_segments_mut(&mut self) -> Result<PathSegmentsMut<'_>, ()>
pub fn path_segments_mut(&mut self) -> Result<PathSegmentsMut<'_>, ()>
Return an object with methods to manipulate this URL’s path segments.
Return Err(()) if this URL is cannot-be-a-base.