pub trait RequestPath: Debug {
// Required method
fn to_sanitized_segments(&self) -> Vec<&str>;
}Expand description
Defines a path that can be used to make a request to an API.
Required Methods
Sourcefn to_sanitized_segments(&self) -> Vec<&str>
fn to_sanitized_segments(&self) -> Vec<&str>
Sanitise the request path by removing empty segments and trimming whitespace and slashes
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".